@@ -1,4 +1,5 @@
 """Single source to the version across setup.py and the whole project.
 """
-__version__ = '0.6'
+from __future__ import unicode_literals
+__version__ = '2.4.2'
 
